/**
 * Copyright (C) 2010 Mycila <mathieu.carbou@gmail.com>
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *         http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package com.mycila.jdbc.tx.sql;

import com.mycila.jdbc.ConnectionFactory;

import javax.inject.Inject;
import javax.inject.Singleton;
import javax.sql.DataSource;
import java.sql.Connection;
import java.sql.SQLException;
import java.util.logging.Level;
import java.util.logging.Logger;

@Singleton
public final class JdbcConnectionFactory implements ConnectionFactory {

    private static final Logger LOGGER = Logger.getLogger(JdbcConnectionFactory.class.getName());

    private final DataSource dataSource;

    @Inject
    public JdbcConnectionFactory(DataSource dataSource) {
        this.dataSource = dataSource;
    }

    @Override
    public Connection getCurrentConnection() {
        ConnectionHolder holder = ConnectionHolder.find(dataSource);
        if (holder != null && holder.hasConnection())
            return holder.getConnection();
        throw new IllegalStateException("No Connection bound to local thread !");
    }

    @Override
    public Connection getNewConnection() {
        if (LOGGER.isLoggable(Level.FINE))
            LOGGER.fine("Getting new JDBC connection");
        try {
            return dataSource.getConnection();
        } catch (SQLException e) {
            throw new IllegalStateException(e.getMessage(), e);
        }
    }
}
